{# Login page
 # Copyright (C) 2020  Đào Dương Hoàng Long
 # Copyright (C) 2020  Nguyễn Gia Phong
 #
 # This file is part of Acanban.
 #
 # Acanban is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published
 # by the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # Acanban is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Affero General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with Acanban.  If not, see <https://www.gnu.org/licenses/>.
 #}

{% extends "base.html" %}
{% block title %}Login{% endblock %}
{% block content %}
<form action=login method=POST class=col-narrow>
  {% if error %}
  <div class=error>{{ error }}</div>
  {% endif %}
  <label for="username">Username</label>
  <input type=text name=username id=username required>
  <label for="password">Password</label>
  <input type=password name=password id=password required>
  <input type=checkbox name=remember id=remember>
  <label for=remember>Remember me</label>
  <button>Login</button>
</form>
{% endblock %}
